

import os

def model1_read():
    _read_file('model1.txt')

def model2_read():
    _read_file('model2.txt')

def model3_read():
    _read_file('model3.txt')

def _read_file(filename):
    base_path = os.path.dirname(__file__)
    file_path = os.path.join(base_path, filename)
    try:
        with open(file_path, 'r') as f:
            print(f.read())
    except FileNotFoundError:
        print(f"{filename} not found.")



from setuptools import setup, find_packages

setup(
    name='gyatModel1',
    version='0.1.2',
    packages=find_packages(),
    include_package_data=True,
    package_data={
        'gyat_module': ['model1.txt', 'model2.txt', 'model3.txt'],
    },
    author='Micheal Scofield',
    description='A sample package that prints text file content',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    classifiers=[
        'Programming Language :: Python :: 3',
    ],
)
